@@ -11,6 +11,7 @@ import sys
 
 from qisys import ui
 import qisys.script
+import qisys.parsers
 import qibuild.parsers
 import qitest.parsers
 import qitest.actions.run
@@ -19,6 +20,7 @@ def configure_parser(parser):
     """Configure parser for this action"""
     qitest.parsers.test_parser(parser)
     qibuild.parsers.project_parser(parser)
+    qisys.parsers.build_parser(parser, include_worktree_parser=False)
     parser.add_argument("-l", "--list", dest="list", action="store_true",
                         help="List what tests would be run")
 
