@@ -11,7 +11,7 @@ import platform
 
 import qisys.sh
 
-def find_lib(paths, name, debug=None, expect_one=True):
+def find_lib(paths, name, debug=None, expect_one=True, shared=None):
     """ Find a library in a list of paths.
 
     :param: debug. If ``None``, looks for both debug and
@@ -35,8 +35,13 @@ def find_lib(paths, name, debug=None, expect_one=True):
     else:
         debug_cases = [debug]
 
+    if shared is None:
+        shared_cases = [True, False]
+    else:
+        shared_cases = [shared]
+
     for debug in debug_cases:
-        for shared in True, False:
+        for shared in shared_cases:
             lib_name = library_name(name, shared=shared, debug=debug)
             for path in paths:
                 lib_path = os.path.join(path, "lib", lib_name)
@@ -132,9 +137,9 @@ def _library_suffix(shared=True, debug=True, os_name=None):
         return debug_suffix + ".lib"
     if os_name == "Linux" and shared is True:
         return ".so"
-    if os_name in ("Linux", "Mac") and shared is False:
+    if os_name in ("Linux", "Darwin") and shared is False:
         return ".a"
-    if os_name == "Mac" and shared:
+    if os_name == "Darwin" and shared:
         return ".dylib"
     return ""
 
