@@ -24,32 +24,26 @@ def main():
         sys.stderr.write("no match for %s\n" % token)
         sys.exit(1)
 
-
 def find_best_match(worktree, token):
     """ Find the best match for a project in a worktree
 
-    It's the shortest basename matching the token if there
-    are no '/' in token, else, the shortest src matching the token
-
     """
-    project_scores = dict()
+    candidates = list()
     for project in worktree.projects:
-        if "/" in token:
-            to_match = project.src
-        else:
-            to_match = os.path.basename(project.src)
-        sequence_matcher = difflib.SequenceMatcher(a=token, b=to_match)
-        project_scores[project] = sequence_matcher.ratio()
-
+        to_match = os.path.basename(project.src)
+        if token in to_match:
+            candidates.append(project)
     max_score = 0
     best_project = None
-    for project, score in project_scores.iteritems():
+    for candidate in candidates:
+        to_match = os.path.basename(candidate.src)
+        sequence_matcher = difflib.SequenceMatcher(a=token, b=to_match)
+        score = sequence_matcher.ratio()
         if score > max_score:
-            best_project = project
             max_score = score
+            best_project = candidate
     if best_project:
         return best_project.path
 
-
 if __name__ == "__main__":
     main()
