@@ -1,6 +1,7 @@
 import os
 
 
+from qisys import ui
 import qisys.worktree
 import qisys.qixml
 
@@ -38,7 +39,9 @@ class LinguistWorkTree(qisys.worktree.WorkTreeObserver):
             if project.name == name:
                 return project
         if raises:
-            raise Exception("No such linguist project: %s" % name)
+            mess = ui.did_you_mean("No such linguist project: %s" % name,
+                                   name, [x.name for x in self.linguist_projects])
+            raise Exception(mess)
         else:
             return None
 
