@@ -9,10 +9,12 @@ import qibuild.parsers
 import qimvn.jar
 
 from qisys import ui
+import qisys.parsers
+import qibuild.parsers
 
 def configure_parser(parser):
     """Configure parser for this action"""
-    qibuild.parsers.build_parser(parser)
+    qibuild.parsers.cmake_build_parser(parser)
     parser.add_argument("jarname")
     parser.add_argument("files", nargs="*")
 
