@@ -5,15 +5,18 @@
 """ Configure all the projects of the given pml file
 """
 
-import qisys.parsers
+import qibuild.parsers
 import qipkg.parsers
 
 def configure_parser(parser):
     """Configure parser for this action"""
     qipkg.parsers.pml_parser(parser)
+    qibuild.parsers.cmake_configure_parser(parser)
+
 
 def do(args):
     """Main entry point"""
+    args.cmake_args = qibuild.parsers.get_cmake_args(args)
     pml_builder = qipkg.parsers.get_pml_builder(args)
     pml_builder.configure()
 
