@@ -53,7 +53,6 @@ class Git(object):
             self._transaction.output += out
         return (retcode, out)
 
-
     def _call(self, *args, **kwargs):
         """ Helper for self.call """
         ui.debug("git", " ".join(args))
@@ -89,7 +88,6 @@ class Git(object):
         yield self._transaction
         self._transaction = None
 
-
     def get_config(self, name):
         """ Get a git config value.
         Return None if not found
@@ -106,6 +104,14 @@ class Git(object):
         """
         self.config(name, value)
 
+    def ls_files(self):
+        """ Calls git ls-files and returns a list """
+        (status, out) = self.call("ls-files", raises=False)
+        if status != 0:
+            return None
+        lines = out.splitlines()
+        return lines
+
     def get_current_ref(self, ref="HEAD"):
         """ return the current ref
         git symbolic-ref HEAD
@@ -126,7 +132,6 @@ class Git(object):
             return branch
         return branch[11:]
 
-
     def get_tracking_branch(self, branch=None):
         if not branch:
             branch = self.get_current_branch()
@@ -185,7 +190,6 @@ class Git(object):
             raise Exception(mess)
         return mess
 
-
     def get_local_branches(self):
         """ Get the list of the local branches in a dict
         master -> tracking branch
@@ -269,7 +273,6 @@ class Git(object):
         rc, _ = self.call("rev-parse", "--verify", "HEAD", raises=False)
         return rc != 0
 
-
     def set_remote(self, name, url):
         """
         Set a new remote with the given name and url
@@ -309,15 +312,7 @@ class Git(object):
                         "refs/heads/%s" % remote_branch)
         return True
 
-    def fetch_default(self, branch):
-        """ Fetch the default remote of branch """
-        if branch.tracks:
-            fetch_cmd = ("fetch", branch.tracks)
-        else:
-            fetch_cmd = ("fetch")
-        self.call(*fetch_cmd)
-
-    def sync_branch(self, branch):
+    def sync_branch(self, branch, fetch_first=True):
         """ git pull --rebase on steroids:
 
          * do not try anything if the worktree is not clean
@@ -335,16 +330,12 @@ class Git(object):
             - False: sync failed
             - True: sync succeeded
         """
+
         remote_branch = branch.remote_branch
         if not remote_branch:
             remote_branch = branch.name
         remote_ref = "%s/%s" % (branch.tracks, remote_branch)
 
-        if branch.tracks:
-            fetch_cmd = ("fetch", branch.tracks)
-        else:
-            fetch_cmd = ("fetch")
-
         ok, mess = self.require_clean_worktree()
         if not ok:
             return None, mess
@@ -362,11 +353,13 @@ class Git(object):
                 # This may fail depending on the user configuration
                 update_cmd = ("rebase", branch.name)
 
+        if fetch_first:
+            rc, out = self.fetch(raises=False)
+            if rc != 0:
+                return False, "Fetch failed\n" + out
+
         update_successful = False
         message = ""
-        (fetch_rc, fetch_out) = self.call(*fetch_cmd, raises=False)
-        if fetch_rc != 0:
-            return False, "Fetch failed:\n" + fetch_out
         (update_rc, out) = self.call(*update_cmd, raises=False)
         if update_rc == 0:
             update_successful = True
@@ -374,13 +367,14 @@ class Git(object):
             if update_cmd[0] == "rebase":
                 # run rebase --abort so that the user is left
                 # in a clean state
-                message = "Rebase failed because of conflicts"
+                message = "Rebase failed with following output\n\n" + out
                 (abort_rc, abort_out) = self.call("rebase", "--abort", raises=False)
                 if abort_rc == 0:
                     return False, message
                 else:
                     full_message = message
-                    full_message += "\nAdditionally, git rebase --abort failed"
+                    full_message += "\n\nAdditionally, git rebase --abort failed "
+                    full_message += "with following output:\n\n"
                     full_message += abort_out
                     return False, full_message
 
@@ -408,17 +402,13 @@ class Git(object):
         if ret == 0:
             return sha1
 
-    def sync_branch_devel(self, local_branch, master_branch):
+    def sync_branch_devel(self, local_branch, master_branch, fetch_first=True):
         """ Make sure master stays compatible with your development branch
         Checks if your local master branch can be fast-forwarded to remote
         Update master's HEAD if it's the case
         """
-
-        if master_branch.tracks:
-            fetch_cmd = ("fetch", master_branch.tracks)
-        else:
-            fetch_cmd = ("fetch")
-        self.call(*fetch_cmd)
+        if fetch_first:
+            self.fetch()
 
         # First check if master can be fast-forwarded
         local_sha1 = self.get_ref_sha1("refs/heads/%s" % master_branch.name)
@@ -481,11 +471,41 @@ class Git(object):
             res.append(commit)
         return res
 
+    def safe_checkout(self, branch, remote, force=False):
+        """ Checkout or create the branch next to the matching
+        remote branch.
+
+        Return either (True, None) if all went well, or
+        (False, error) in case of error
+        """
+        current_branch = self.get_current_branch()
+        if not current_branch:
+            return False, "not on any branch, skipping"
+        clean, error = self.require_clean_worktree()
+        if not clean and not force:
+            return False, error
+        ref = "%s/%s" % (remote, branch)
+        # Fetch if necessary:
+        rc, out = self.call("show-ref", ref, raises=False)
+        if rc != 0:
+            self.fetch(remote)
+        # If it is still not here, do not use --track
+        rc, out = self.call("show-ref", ref, raises=False)
+        if rc == 0:
+            checkout_args = ["-B", branch, "--track", ref]
+        else:
+            checkout_args = ["-B", branch]
+        if force:
+            checkout_args.append("--force")
+        rc, out = self.checkout(*checkout_args, raises=False)
+        if rc != 0:
+            return False, "Checkout failed " + out
+        return True, None
+
     def __repr__(self):
         return "<Git repo in %s>" % self.repo
 
 
-
 def get_repo_root(path):
     """Return the root dir of a git worktree given a path.
 
@@ -502,6 +522,7 @@ def get_repo_root(path):
         return None
     return qisys.sh.to_native_path(out)
 
+
 def is_submodule(path):
     """ Tell if the given path is a submodule
 
@@ -538,10 +559,12 @@ def is_submodule(path):
                    "\nError was: ", ui.reset, "\n", "  " + out)
         return True
 
+
 def is_git(path):
     """Return true if .git directory exists"""
     return os.path.isdir(os.path.join(path, ".git"))
 
+
 def name_from_url(url):
     """ Return the project name from the url
     Assume there project name is always in the form
@@ -576,3 +599,24 @@ class Transaction:
     def __init__(self):
         self.ok = True
         self.output = ""
+
+def get_status(git, local_ref, remote_ref):
+    """Check if local_ref is ahead and / or behind remote_ref """
+    behind = 0
+    ahead = 0
+    (ret, out) = git.call("rev-list", "--left-right",
+                          "%s..%s" % (remote_ref, local_ref), raises=False)
+    if ret == 0:
+        ahead = len(out.split())
+    (ret, out) = git.call("rev-list", "--left-right",
+                          "%s..%s" % (local_ref, remote_ref), raises=False)
+    if ret == 0:
+        behind = len(out.split())
+    if not ahead and not behind:
+        return "no-diff"
+    if ahead and not behind:
+        return "ahead"
+    if behind and not ahead:
+        return "behind"
+    if ahead and behind:
+        return "diverged"
