@@ -36,7 +36,6 @@ def test_normalize_path(tmpdir):
     assert worktree.normalize_path(foo_abs_path) == "bar/foo"
     assert worktree.normalize_path("bar/foo") == "bar/foo"
 
-
 def test_add_project_simple(worktree):
     # pylint: disable-msg=E1101
     tmp = py.path.local(worktree.root)
@@ -46,7 +45,6 @@ def test_add_project_simple(worktree):
     foo = worktree.get_project("foo")
     assert foo.src == "foo"
 
-
 def test_fails_when_root_does_not_exists(tmpdir):
     non_exitsting = tmpdir.join("doesnotexist")
     # pylint: disable-msg=E1101
@@ -64,8 +62,6 @@ def test_ignore_src_dot(tmpdir):
     worktree  = qisys.worktree.WorkTree(tmpdir.strpath)
     worktree.add_project("foo")
 
-
-
 def test_remove_project(worktree):
     # pylint: disable-msg=E1101
     tmp = py.path.local(worktree.root)
@@ -86,7 +82,6 @@ def test_remove_project(worktree):
     assert worktree.projects == list()
     assert not os.path.exists(foo_src.strpath)
 
-
 def test_nested_qiprojects(tmpdir):
     a_project = tmpdir.mkdir("a")
     worktree_xml = tmpdir.mkdir(".qi").join("worktree.xml")
@@ -120,7 +115,6 @@ def test_nested_qiprojects(tmpdir):
     assert [p.src for p in worktree.projects] == \
         ["a", "a/b", "a/b/c"]
 
-
 def test_non_exiting_path_are_removed(tmpdir, interact):
     # all projects registered should exist:
     wt = qisys.worktree.WorkTree(tmpdir.strpath)
@@ -130,7 +124,6 @@ def test_non_exiting_path_are_removed(tmpdir, interact):
     wt2 = qisys.worktree.WorkTree(tmpdir.strpath)
     assert wt2.projects == list()
 
-
 def test_check_subprojects_exist(tmpdir):
     # subprojets in qiproject.xml should exist
     wt = qisys.worktree.WorkTree(tmpdir.strpath)
@@ -152,7 +145,6 @@ def test_observers_are_notified(worktree):
     worktree.create_project("foo")
     assert mock_observer.on_project_added.called
 
-
 def test_add_nested_projects(worktree):
     worktree.create_project("foo")
     tmpdir = worktree.tmpdir
@@ -168,3 +160,11 @@ def test_add_nested_projects(worktree):
 
     worktree.remove_project("spam")
     assert [p.src for p in worktree.projects] == ["foo"]
+
+def test_warns_on_nested_worktrees(tmpdir, record_messages):
+    work1 = tmpdir.mkdir("work1")
+    work1.mkdir(".qi")
+    work2 = work1.mkdir("work2")
+    work2.mkdir(".qi")
+    wt2 = qisys.worktree.WorkTree(work2.strpath)
+    assert record_messages.find("Nested worktrees")
