@@ -16,14 +16,16 @@ def configure_parser(parser):
     parser.add_argument("name",
         help="The name of the toolchain to remove")
     parser.add_argument('-f', "--force",
-        dest="force_remove", action="store_true",
+        dest="force", action="store_true",
         help="""remove the whole toolchain, including any local packages you may
              have added to the toolchain.""")
 
 def do(args):
     """ Main entry point  """
-    force_rm = args.force_remove
     tc = qitoolchain.get_toolchain(args.name)
-    ui.info(ui.green, "Removing toolchain", ui.blue, tc.name)
-    tc.remove(force_remove=force_rm)
-    ui.info(ui.green, "done")
+    if args.force:
+        ui.info(ui.green, "Removing toolchain", ui.blue, tc.name)
+        tc.remove()
+        ui.info(ui.green, "done")
+    else:
+        ui.info("Would remove toolchain", ui.blue, tc.name)
