@@ -4,7 +4,7 @@ import pytest
 
 def test_simple(qitoolchain_action):
     qitoolchain.toolchain.Toolchain("foo")
-    qitoolchain_action("remove", "foo")
+    qitoolchain_action("remove", "-f", "foo")
     # pylint: disable-msg=E1101
     with pytest.raises(Exception):
         qitoolchain.get_toolchain("foo")
